@@ -1,6 +1,6 @@
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
-# For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
-# Copyright (c) https://github.com/PyCQA/astroid/blob/main/CONTRIBUTORS.txt
+# For details: https://github.com/pylint-dev/astroid/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/astroid/blob/main/CONTRIBUTORS.txt
 
 """The AstroidBuilder makes astroid from living object and / or from _ast.
 
@@ -17,19 +17,12 @@ import types
 from collections.abc import Iterator, Sequence
 from io import TextIOWrapper
 from tokenize import detect_encoding
-from typing import TYPE_CHECKING
 
 from astroid import bases, modutils, nodes, raw_building, rebuilder, util
 from astroid._ast import ParserModule, get_parser_module
 from astroid.exceptions import AstroidBuildingError, AstroidSyntaxError, InferenceError
 from astroid.manager import AstroidManager
 
-if TYPE_CHECKING:
-    from astroid import objects
-else:
-    objects = util.lazy_import("objects")
-
-
 # The name of the transient function that is used to
 # wrap expressions to be extracted when calling
 # extract_node.
@@ -76,6 +69,8 @@ class AstroidBuilder(raw_building.InspectBuilder):
     ) -> None:
         super().__init__(manager)
         self._apply_transforms = apply_transforms
+        if not raw_building.InspectBuilder.bootstrapped:
+            raw_building._astroid_bootstrapping()
 
     def module_build(
         self, module: types.ModuleType, modname: str | None = None
@@ -235,10 +230,11 @@ class AstroidBuilder(raw_building.InspectBuilder):
 
         This adds name to locals and handle members definition.
         """
+        from astroid import objects  # pylint: disable=import-outside-toplevel
+
         try:
-            frame = node.frame(future=True)
             for inferred in node.expr.infer():
-                if inferred is util.Uninferable:
+                if isinstance(inferred, util.UninferableBase):
                     continue
                 try:
                     # pylint: disable=unidiomatic-typecheck # We want a narrow check on the
@@ -255,10 +251,7 @@ class AstroidBuilder(raw_building.InspectBuilder):
                         # Const, Tuple or other containers that inherit from
                         # `Instance`
                         continue
-                    elif (
-                        isinstance(inferred, bases.Proxy)
-                        or inferred is util.Uninferable
-                    ):
+                    elif isinstance(inferred, (bases.Proxy, util.UninferableBase)):
                         continue
                     elif inferred.is_function:
                         iattrs = inferred.instance_attrs
@@ -270,22 +263,15 @@ class AstroidBuilder(raw_building.InspectBuilder):
                 values = iattrs.setdefault(node.attrname, [])
                 if node in values:
                     continue
-                # get assign in __init__ first XXX useful ?
-                if (
-                    frame.name == "__init__"
-                    and values
-                    and values[0].frame(future=True).name != "__init__"
-                ):
-                    values.insert(0, node)
-                else:
-                    values.append(node)
+                values.append(node)
         except InferenceError:
             pass
 
 
 def build_namespace_package_module(name: str, path: Sequence[str]) -> nodes.Module:
-    # TODO: Typing: Remove the cast to list and just update typing to accept Sequence
-    return nodes.Module(name, path=list(path), package=True)
+    module = nodes.Module(name, path=path, package=True)
+    module.postinit(body=[], doc_node=None)
+    return module
 
 
 def parse(
