@@ -1,6 +1,6 @@
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
-# For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
-# Copyright (c) https://github.com/PyCQA/astroid/blob/main/CONTRIBUTORS.txt
+# For details: https://github.com/pylint-dev/astroid/blob/main/LICENSE
+# Copyright (c) https://github.com/pylint-dev/astroid/blob/main/CONTRIBUTORS.txt
 
 """
 Data object model, as per https://docs.python.org/3/reference/datamodel.html.
@@ -26,10 +26,10 @@ from __future__ import annotations
 import itertools
 import os
 import pprint
-import sys
 import types
+from collections.abc import Iterator
 from functools import lru_cache
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, Literal
 
 import astroid
 from astroid import bases, nodes, util
@@ -37,17 +37,9 @@ from astroid.context import InferenceContext, copy_context
 from astroid.exceptions import AttributeInferenceError, InferenceError, NoDefault
 from astroid.manager import AstroidManager
 from astroid.nodes import node_classes
-
-objects = util.lazy_import("objects")
-builder = util.lazy_import("builder")
-
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from astroid.typing import InferenceResult, SuccessfulInferenceResult
 
 if TYPE_CHECKING:
-    from astroid import builder
     from astroid.objects import Property
 
 IMPL_PREFIX = "attr_"
@@ -55,7 +47,13 @@ LEN_OF_IMPL_PREFIX = len(IMPL_PREFIX)
 
 
 def _dunder_dict(instance, attributes):
-    obj = node_classes.Dict(parent=instance)
+    obj = node_classes.Dict(
+        parent=instance,
+        lineno=instance.lineno,
+        col_offset=instance.col_offset,
+        end_lineno=instance.end_lineno,
+        end_col_offset=instance.end_col_offset,
+    )
 
     # Convert the keys to node strings
     keys = [
@@ -119,7 +117,7 @@ class ObjectModel:
     def __contains__(self, name) -> bool:
         return name in self.attributes()
 
-    @lru_cache()  # noqa
+    @lru_cache  # noqa
     def attributes(self) -> list[str]:
         """Get the attributes which are exported by this object model."""
         return [o[LEN_OF_IMPL_PREFIX:] for o in dir(self) if o.startswith(IMPL_PREFIX)]
@@ -137,6 +135,8 @@ class ObjectModel:
     @property
     def attr___new__(self) -> bases.BoundMethod:
         """Calling cls.__new__(type) on an object returns an instance of 'type'."""
+        from astroid import builder  # pylint: disable=import-outside-toplevel
+
         node: nodes.FunctionDef = builder.extract_node(
             """def __new__(self, cls): return cls()"""
         )
@@ -149,6 +149,8 @@ class ObjectModel:
     @property
     def attr___init__(self) -> bases.BoundMethod:
         """Calling cls.__init__() normally returns None."""
+        from astroid import builder  # pylint: disable=import-outside-toplevel
+
         # The *args and **kwargs are necessary not to trigger warnings about missing
         # or extra parameters for '__init__' methods we don't infer correctly.
         # This BoundMethod is the fallback value for those.
@@ -267,7 +269,13 @@ class FunctionModel(ObjectModel):
 
     @property
     def attr___annotations__(self):
-        obj = node_classes.Dict(parent=self._instance)
+        obj = node_classes.Dict(
+            parent=self._instance,
+            lineno=self._instance.lineno,
+            col_offset=self._instance.col_offset,
+            end_lineno=self._instance.end_lineno,
+            end_col_offset=self._instance.end_col_offset,
+        )
 
         if not self._instance.returns:
             returns = None
@@ -301,7 +309,13 @@ class FunctionModel(ObjectModel):
 
     @property
     def attr___dict__(self):
-        return node_classes.Dict(parent=self._instance)
+        return node_classes.Dict(
+            parent=self._instance,
+            lineno=self._instance.lineno,
+            col_offset=self._instance.col_offset,
+            end_lineno=self._instance.end_lineno,
+            end_col_offset=self._instance.end_col_offset,
+        )
 
     attr___globals__ = attr___dict__
 
@@ -318,7 +332,13 @@ class FunctionModel(ObjectModel):
                 yield name, default
 
         args = self._instance.args
-        obj = node_classes.Dict(parent=self._instance)
+        obj = node_classes.Dict(
+            parent=self._instance,
+            lineno=self._instance.lineno,
+            col_offset=self._instance.col_offset,
+            end_lineno=self._instance.end_lineno,
+            end_col_offset=self._instance.end_col_offset,
+        )
         defaults = dict(_default_args(args, obj))
 
         obj.postinit(list(defaults.items()))
@@ -343,8 +363,10 @@ class FunctionModel(ObjectModel):
                 return 0
 
             def infer_call_result(
-                self, caller, context: InferenceContext | None = None
-            ):
+                self,
+                caller: SuccessfulInferenceResult | None,
+                context: InferenceContext | None = None,
+            ) -> Iterator[bases.BoundMethod]:
                 if len(caller.args) > 2 or len(caller.args) < 1:
                     raise InferenceError(
                         "Invalid arguments for descriptor binding",
@@ -358,7 +380,7 @@ class FunctionModel(ObjectModel):
                 except StopIteration as e:
                     raise InferenceError(context=context, node=caller.args[0]) from e
 
-                if cls is astroid.Uninferable:
+                if isinstance(cls, util.UninferableBase):
                     raise InferenceError(
                         "Invalid class inferred", target=self, context=context
                     )
@@ -376,6 +398,8 @@ class FunctionModel(ObjectModel):
                     lineno=func.lineno,
                     col_offset=func.col_offset,
                     parent=func.parent,
+                    end_lineno=func.end_lineno,
+                    end_col_offset=func.end_col_offset,
                 )
                 # pylint: disable=no-member
                 new_func.postinit(
@@ -403,12 +427,24 @@ class FunctionModel(ObjectModel):
                 we get a new object which has two parameters, *self* and *type*.
                 """
                 nonlocal func
+                arguments = astroid.Arguments(
+                    parent=func.args.parent, vararg=None, kwarg=None
+                )
+
                 positional_or_keyword_params = func.args.args.copy()
-                positional_or_keyword_params.append(astroid.AssignName(name="type"))
+                positional_or_keyword_params.append(
+                    astroid.AssignName(
+                        name="type",
+                        lineno=0,
+                        col_offset=0,
+                        parent=arguments,
+                        end_lineno=None,
+                        end_col_offset=None,
+                    )
+                )
 
                 positional_only_params = func.args.posonlyargs.copy()
 
-                arguments = astroid.Arguments(parent=func.args.parent)
                 arguments.postinit(
                     args=positional_or_keyword_params,
                     posonlyargs=positional_only_params,
@@ -416,6 +452,8 @@ class FunctionModel(ObjectModel):
                     kwonlyargs=[],
                     kw_defaults=[],
                     annotations=[],
+                    kwonlyargs_annotations=[],
+                    posonlyargs_annotations=[],
                 )
                 return arguments
 
@@ -491,8 +529,10 @@ class ClassModel(ObjectModel):
         # The method we're returning is capable of inferring the underlying MRO though.
         class MroBoundMethod(bases.BoundMethod):
             def infer_call_result(
-                self, caller, context: InferenceContext | None = None
-            ):
+                self,
+                caller: SuccessfulInferenceResult | None,
+                context: InferenceContext | None = None,
+            ) -> Iterator[node_classes.Tuple]:
                 yield other_self.attr___mro__
 
         implicit_metaclass = self._instance.implicit_metaclass()
@@ -539,8 +579,10 @@ class ClassModel(ObjectModel):
 
         class SubclassesBoundMethod(bases.BoundMethod):
             def infer_call_result(
-                self, caller, context: InferenceContext | None = None
-            ):
+                self,
+                caller: SuccessfulInferenceResult | None,
+                context: InferenceContext | None = None,
+            ) -> Iterator[node_classes.List]:
                 yield obj
 
         implicit_metaclass = self._instance.implicit_metaclass()
@@ -549,7 +591,13 @@ class ClassModel(ObjectModel):
 
     @property
     def attr___dict__(self):
-        return node_classes.Dict(parent=self._instance)
+        return node_classes.Dict(
+            parent=self._instance,
+            lineno=self._instance.lineno,
+            col_offset=self._instance.col_offset,
+            end_lineno=self._instance.end_lineno,
+            end_col_offset=self._instance.end_col_offset,
+        )
 
     @property
     def attr___call__(self):
@@ -612,6 +660,8 @@ class ContextManagerModel(ObjectModel):
         will bind this method's return value to the target(s) specified in the
         as clause of the statement, if any.
         """
+        from astroid import builder  # pylint: disable=import-outside-toplevel
+
         node: nodes.FunctionDef = builder.extract_node("""def __enter__(self): ...""")
         # We set the parent as being the ClassDef of 'object' as that
         # is where this method originally comes from
@@ -628,6 +678,8 @@ class ContextManagerModel(ObjectModel):
         exception that caused the context to be exited. If the context was exited
         without an exception, all three arguments will be None.
         """
+        from astroid import builder  # pylint: disable=import-outside-toplevel
+
         node: nodes.FunctionDef = builder.extract_node(
             """def __exit__(self, exc_type, exc_value, traceback): ..."""
         )
@@ -803,8 +855,10 @@ class DictModel(ObjectModel):
 
         class DictMethodBoundMethod(astroid.BoundMethod):
             def infer_call_result(
-                self, caller, context: InferenceContext | None = None
-            ):
+                self,
+                caller: SuccessfulInferenceResult | None,
+                context: InferenceContext | None = None,
+            ) -> Iterator[InferenceResult]:
                 yield obj
 
         meth = next(self._instance._proxied.igetattr(name), None)
@@ -812,6 +866,8 @@ class DictModel(ObjectModel):
 
     @property
     def attr_items(self):
+        from astroid import objects  # pylint: disable=import-outside-toplevel
+
         elems = []
         obj = node_classes.List(parent=self._instance)
         for key, value in self._instance.items:
@@ -820,35 +876,46 @@ class DictModel(ObjectModel):
             elems.append(elem)
         obj.postinit(elts=elems)
 
-        obj = objects.DictItems(obj)
-        return self._generic_dict_attribute(obj, "items")
+        items_obj = objects.DictItems(obj)
+        return self._generic_dict_attribute(items_obj, "items")
 
     @property
     def attr_keys(self):
+        from astroid import objects  # pylint: disable=import-outside-toplevel
+
         keys = [key for (key, _) in self._instance.items]
         obj = node_classes.List(parent=self._instance)
         obj.postinit(elts=keys)
 
-        obj = objects.DictKeys(obj)
-        return self._generic_dict_attribute(obj, "keys")
+        keys_obj = objects.DictKeys(obj)
+        return self._generic_dict_attribute(keys_obj, "keys")
 
     @property
     def attr_values(self):
+        from astroid import objects  # pylint: disable=import-outside-toplevel
+
         values = [value for (_, value) in self._instance.items]
         obj = node_classes.List(parent=self._instance)
         obj.postinit(values)
 
-        obj = objects.DictValues(obj)
-        return self._generic_dict_attribute(obj, "values")
+        values_obj = objects.DictValues(obj)
+        return self._generic_dict_attribute(values_obj, "values")
 
 
 class PropertyModel(ObjectModel):
     """Model for a builtin property."""
 
     def _init_function(self, name):
-        function = nodes.FunctionDef(name=name, parent=self._instance)
+        function = nodes.FunctionDef(
+            name=name,
+            parent=self._instance,
+            lineno=self._instance.lineno,
+            col_offset=self._instance.col_offset,
+            end_lineno=self._instance.end_lineno,
+            end_col_offset=self._instance.end_col_offset,
+        )
 
-        args = nodes.Arguments(parent=function)
+        args = nodes.Arguments(parent=function, vararg=None, kwarg=None)
         args.postinit(
             args=[],
             defaults=[],
@@ -869,8 +936,10 @@ class PropertyModel(ObjectModel):
 
         class PropertyFuncAccessor(nodes.FunctionDef):
             def infer_call_result(
-                self, caller=None, context: InferenceContext | None = None
-            ):
+                self,
+                caller: SuccessfulInferenceResult | None,
+                context: InferenceContext | None = None,
+            ) -> Iterator[InferenceResult]:
                 nonlocal func
                 if caller and len(caller.args) != 1:
                     raise InferenceError(
@@ -881,7 +950,14 @@ class PropertyModel(ObjectModel):
                     caller=caller, context=context
                 )
 
-        property_accessor = PropertyFuncAccessor(name="fget", parent=self._instance)
+        property_accessor = PropertyFuncAccessor(
+            name="fget",
+            parent=self._instance,
+            lineno=self._instance.lineno,
+            col_offset=self._instance.col_offset,
+            end_lineno=self._instance.end_lineno,
+            end_col_offset=self._instance.end_col_offset,
+        )
         property_accessor.postinit(args=func.args, body=func.body)
         return property_accessor
 
@@ -912,8 +988,10 @@ class PropertyModel(ObjectModel):
 
         class PropertyFuncAccessor(nodes.FunctionDef):
             def infer_call_result(
-                self, caller=None, context: InferenceContext | None = None
-            ):
+                self,
+                caller: SuccessfulInferenceResult | None,
+                context: InferenceContext | None = None,
+            ) -> Iterator[InferenceResult]:
                 nonlocal func_setter
                 if caller and len(caller.args) != 2:
                     raise InferenceError(
@@ -921,7 +999,14 @@ class PropertyModel(ObjectModel):
                     )
                 yield from func_setter.infer_call_result(caller=caller, context=context)
 
-        property_accessor = PropertyFuncAccessor(name="fset", parent=self._instance)
+        property_accessor = PropertyFuncAccessor(
+            name="fset",
+            parent=self._instance,
+            lineno=self._instance.lineno,
+            col_offset=self._instance.col_offset,
+            end_lineno=self._instance.end_lineno,
+            end_col_offset=self._instance.end_col_offset,
+        )
         property_accessor.postinit(args=func_setter.args, body=func_setter.body)
         return property_accessor
 
